@@ -36,10 +36,8 @@ class CfnCluster(
 ):
     """A CloudFormation ``AWS::DAX::Cluster``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DAX::Cluster
+    :cloudformationResource: AWS::DAX::Cluster
     """
 
     def __init__(
@@ -57,7 +55,7 @@ class CfnCluster(
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
         security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
-        sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]] = None,
+        sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -99,11 +97,10 @@ class CfnCluster(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -128,8 +125,7 @@ class CfnCluster(
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: Arn
+        :cloudformationAttribute: Arn
         """
         return jsii.get(self, "attrArn")
 
@@ -137,8 +133,7 @@ class CfnCluster(
     @jsii.member(jsii_name="attrClusterDiscoveryEndpoint")
     def attr_cluster_discovery_endpoint(self) -> builtins.str:
         """
-        cloudformationAttribute:
-        :cloudformationAttribute:: ClusterDiscoveryEndpoint
+        :cloudformationAttribute: ClusterDiscoveryEndpoint
         """
         return jsii.get(self, "attrClusterDiscoveryEndpoint")
 
@@ -152,7 +147,6 @@ class CfnCluster(
     def tags(self) -> aws_cdk.core.TagManager:
         """``AWS::DAX::Cluster.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
         """
         return jsii.get(self, "tags")
@@ -162,7 +156,6 @@ class CfnCluster(
     def iam_role_arn(self) -> builtins.str:
         """``AWS::DAX::Cluster.IAMRoleARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
         """
         return jsii.get(self, "iamRoleArn")
@@ -176,7 +169,6 @@ class CfnCluster(
     def node_type(self) -> builtins.str:
         """``AWS::DAX::Cluster.NodeType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
         """
         return jsii.get(self, "nodeType")
@@ -190,7 +182,6 @@ class CfnCluster(
     def replication_factor(self) -> jsii.Number:
         """``AWS::DAX::Cluster.ReplicationFactor``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
         """
         return jsii.get(self, "replicationFactor")
@@ -204,7 +195,6 @@ class CfnCluster(
     def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.AvailabilityZones``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-availabilityzones
         """
         return jsii.get(self, "availabilityZones")
@@ -221,7 +211,6 @@ class CfnCluster(
     def cluster_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ClusterName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clustername
         """
         return jsii.get(self, "clusterName")
@@ -235,7 +224,6 @@ class CfnCluster(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-description
         """
         return jsii.get(self, "description")
@@ -249,7 +237,6 @@ class CfnCluster(
     def notification_topic_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.NotificationTopicARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-notificationtopicarn
         """
         return jsii.get(self, "notificationTopicArn")
@@ -263,7 +250,6 @@ class CfnCluster(
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-parametergroupname
         """
         return jsii.get(self, "parameterGroupName")
@@ -277,7 +263,6 @@ class CfnCluster(
     def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-preferredmaintenancewindow
         """
         return jsii.get(self, "preferredMaintenanceWindow")
@@ -294,7 +279,6 @@ class CfnCluster(
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.SecurityGroupIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-securitygroupids
         """
         return jsii.get(self, "securityGroupIds")
@@ -310,10 +294,9 @@ class CfnCluster(
     @jsii.member(jsii_name="sseSpecification")
     def sse_specification(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-ssespecification
         """
         return jsii.get(self, "sseSpecification")
@@ -321,7 +304,7 @@ class CfnCluster(
     @sse_specification.setter # type: ignore
     def sse_specification(
         self,
-        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]],
     ) -> None:
         jsii.set(self, "sseSpecification", value)
 
@@ -330,7 +313,6 @@ class CfnCluster(
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-subnetgroupname
         """
         return jsii.get(self, "subnetGroupName")
@@ -353,7 +335,6 @@ class CfnCluster(
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html
             """
             self._values: typing.Dict[str, typing.Any] = {}
@@ -366,7 +347,6 @@ class CfnCluster(
         ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
             """``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
-            see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html#cfn-dax-cluster-ssespecification-sseenabled
             """
             result = self._values.get("sse_enabled")
@@ -417,7 +397,7 @@ class CfnClusterProps:
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
         security_group_ids: typing.Optional[typing.List[builtins.str]] = None,
-        sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]] = None,
+        sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnCluster.SSESpecificationProperty]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
         tags: typing.Any = None,
     ) -> None:
@@ -437,7 +417,6 @@ class CfnClusterProps:
         :param subnet_group_name: ``AWS::DAX::Cluster.SubnetGroupName``.
         :param tags: ``AWS::DAX::Cluster.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -470,7 +449,6 @@ class CfnClusterProps:
     def iam_role_arn(self) -> builtins.str:
         """``AWS::DAX::Cluster.IAMRoleARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
         """
         result = self._values.get("iam_role_arn")
@@ -481,7 +459,6 @@ class CfnClusterProps:
     def node_type(self) -> builtins.str:
         """``AWS::DAX::Cluster.NodeType``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
         """
         result = self._values.get("node_type")
@@ -492,7 +469,6 @@ class CfnClusterProps:
     def replication_factor(self) -> jsii.Number:
         """``AWS::DAX::Cluster.ReplicationFactor``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
         """
         result = self._values.get("replication_factor")
@@ -503,7 +479,6 @@ class CfnClusterProps:
     def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.AvailabilityZones``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-availabilityzones
         """
         result = self._values.get("availability_zones")
@@ -513,7 +488,6 @@ class CfnClusterProps:
     def cluster_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ClusterName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-clustername
         """
         result = self._values.get("cluster_name")
@@ -523,7 +497,6 @@ class CfnClusterProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-description
         """
         result = self._values.get("description")
@@ -533,7 +506,6 @@ class CfnClusterProps:
     def notification_topic_arn(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.NotificationTopicARN``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-notificationtopicarn
         """
         result = self._values.get("notification_topic_arn")
@@ -543,7 +515,6 @@ class CfnClusterProps:
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-parametergroupname
         """
         result = self._values.get("parameter_group_name")
@@ -553,7 +524,6 @@ class CfnClusterProps:
     def preferred_maintenance_window(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-preferredmaintenancewindow
         """
         result = self._values.get("preferred_maintenance_window")
@@ -563,7 +533,6 @@ class CfnClusterProps:
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         """``AWS::DAX::Cluster.SecurityGroupIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-securitygroupids
         """
         result = self._values.get("security_group_ids")
@@ -572,10 +541,9 @@ class CfnClusterProps:
     @builtins.property
     def sse_specification(
         self,
-    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnCluster.SSESpecificationProperty]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-ssespecification
         """
         result = self._values.get("sse_specification")
@@ -585,7 +553,6 @@ class CfnClusterProps:
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::Cluster.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-subnetgroupname
         """
         result = self._values.get("subnet_group_name")
@@ -595,7 +562,6 @@ class CfnClusterProps:
     def tags(self) -> typing.Any:
         """``AWS::DAX::Cluster.Tags``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
         """
         result = self._values.get("tags")
@@ -621,10 +587,8 @@ class CfnParameterGroup(
 ):
     """A CloudFormation ``AWS::DAX::ParameterGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DAX::ParameterGroup
+    :cloudformationResource: AWS::DAX::ParameterGroup
     """
 
     def __init__(
@@ -654,11 +618,10 @@ class CfnParameterGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -689,7 +652,6 @@ class CfnParameterGroup(
     def parameter_name_values(self) -> typing.Any:
         """``AWS::DAX::ParameterGroup.ParameterNameValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
         """
         return jsii.get(self, "parameterNameValues")
@@ -703,7 +665,6 @@ class CfnParameterGroup(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-description
         """
         return jsii.get(self, "description")
@@ -717,7 +678,6 @@ class CfnParameterGroup(
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parametergroupname
         """
         return jsii.get(self, "parameterGroupName")
@@ -750,7 +710,6 @@ class CfnParameterGroupProps:
         :param parameter_group_name: ``AWS::DAX::ParameterGroup.ParameterGroupName``.
         :param parameter_name_values: ``AWS::DAX::ParameterGroup.ParameterNameValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -765,7 +724,6 @@ class CfnParameterGroupProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-description
         """
         result = self._values.get("description")
@@ -775,7 +733,6 @@ class CfnParameterGroupProps:
     def parameter_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::ParameterGroup.ParameterGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parametergroupname
         """
         result = self._values.get("parameter_group_name")
@@ -785,7 +742,6 @@ class CfnParameterGroupProps:
     def parameter_name_values(self) -> typing.Any:
         """``AWS::DAX::ParameterGroup.ParameterNameValues``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
         """
         result = self._values.get("parameter_name_values")
@@ -811,10 +767,8 @@ class CfnSubnetGroup(
 ):
     """A CloudFormation ``AWS::DAX::SubnetGroup``.
 
-    see
     :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
-    cloudformationResource:
-    :cloudformationResource:: AWS::DAX::SubnetGroup
+    :cloudformationResource: AWS::DAX::SubnetGroup
     """
 
     def __init__(
@@ -844,11 +798,10 @@ class CfnSubnetGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """Examines the CloudFormation resource and discloses attributes.
+        """(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "inspect", [inspector])
@@ -879,7 +832,6 @@ class CfnSubnetGroup(
     def subnet_ids(self) -> typing.List[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
         """
         return jsii.get(self, "subnetIds")
@@ -893,7 +845,6 @@ class CfnSubnetGroup(
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-description
         """
         return jsii.get(self, "description")
@@ -907,7 +858,6 @@ class CfnSubnetGroup(
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetgroupname
         """
         return jsii.get(self, "subnetGroupName")
@@ -940,7 +890,6 @@ class CfnSubnetGroupProps:
         :param description: ``AWS::DAX::SubnetGroup.Description``.
         :param subnet_group_name: ``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -955,7 +904,6 @@ class CfnSubnetGroupProps:
     def subnet_ids(self) -> typing.List[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetIds``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
         """
         result = self._values.get("subnet_ids")
@@ -966,7 +914,6 @@ class CfnSubnetGroupProps:
     def description(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.Description``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-description
         """
         result = self._values.get("description")
@@ -976,7 +923,6 @@ class CfnSubnetGroupProps:
     def subnet_group_name(self) -> typing.Optional[builtins.str]:
         """``AWS::DAX::SubnetGroup.SubnetGroupName``.
 
-        see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetgroupname
         """
         result = self._values.get("subnet_group_name")
